/**
 * SAUserPrefs plugin styles
 */

#address-rules-cont,
#spam-langs-cont
{
  height: 200px;
  overflow: auto;
  width: 100%;
}

body.address-rules-table,
body.spam-langs-table
{
  margin: 0px;
}

table.address-rules-table,
table.spam-langs-table
{
  width: 100%;
  display: table;
  table-layout: fixed;
  border: 0;
}

table.address-rules-table thead th,
table.spam-langs-table thead th
{
  background: none;
  background-color: #CCC;
  font-weight: bold;
  color: #000;
}

table.address-rules-table thead th a,
table.spam-langs-table thead th a
{
  color: #000;
  padding: 0;
}

table.address-rules-table thead th a:focus,
table.spam-langs-table thead th a:focus
{
  color: #000;
  font-weight: normal;
  background-color: transparent;
  text-shadow: none;
}

table.spam-langs-table tr > .lang
{
  width: 90%;
}

table.spam-langs-table tr > .tick
{
  width: 10%;
}

table.spam-langs-table thead th.tick a
{
  padding-right: 24px;
}

table.address-rules-table thead th.sortedASC a,
table.spam-langs-table thead th.sortedASC a
{
  text-decoration: underline;
  background: url(images/listicons.png) no-repeat right -298px;
}

table.address-rules-table thead th.sortedDESC a,
table.spam-langs-table thead th.sortedDESC a
{
  text-decoration: underline;
  background: url(images/listicons.png) no-repeat right -330px;
}

table.address-rules-table thead th.rule
{
  width: 180px;
}

table.address-rules-table thead th.control
{
  width: 40px;
}

table.spam-langs-table tr > .lang,
table.address-rules-table tr > .rule,
table.address-rules-table tr > .email
{
  text-align: left;
  vertical-align: middle;
  border-left: 0;
  border-right: 0;
}

table.spam-langs-table tr > .tick,
table.address-rules-table tr > .control
{
  text-align: right;
  vertical-align: middle;
  border-left: 0;
  border-right: 0;
}

table.spam-langs-table tbody td.tick a,
table.address-rules-table tbody td.control a
{
  display: block;
  float: right;
  width: 16px;
  height: 16px;
  background-image: url(images/icons.png);
  cursor: pointer;
}

table.address-rules-table tr > .control a.delete
{
  background-position: 0 -1px;
}

table.spam-langs-table tr > .tick a.enabled
{
  background-position: 0 -18px;
}

table.spam-langs-table tr > .tick a.disabled
{
  background-position: 0 -36px;
}

.whitelist_from,
.whitelist_to
{
  color: #008800;
  text-align: left;
  vertical-align: middle;
}

.blacklist_from
{
  color: #BB0000;
  text-align: left;
  vertical-align: middle;
}

#listcontrols
{
  font-size: 11px;
  text-align: right;
}

#listcontrols a,
#listcontrols a:active,
#listcontrols a:visited
{
  color: #2D5986;
  font-size: 11px;
  text-decoration: none;
}

#listcontrols a:hover
{
  text-decoration: underline;
}

table.generalprefstable,
table.langprefstable,
table.headersprefstable,
table.testsprefstable,
table.bayesprefstable,
table.reportprefstable,
table.addressprefstable
{
  width: 100%;
  border-spacing: 0;
  border-collapse: collapse;
}

table.generalprefstable td,
table.langprefstable td,
table.headersprefstable td,
table.testsprefstable td,
table.bayesprefstable td,
table.reportprefstable td,
table.addressprefstable td
{
  width: 80%;
  padding: 4px 10px;
  background: #eee;
  border-bottom: 2px solid #fff;
}

table.addressprefstable td
{
  width: auto;
}

table.generalprefstable tr > .title,
table.langprefstable tr > .title,
table.headersprefstable tr > .title,
table.testsprefstable tr > .title,
table.bayesprefstable tr > .title,
table.reportprefstable tr > .title,
table.addressprefstable tr > .title
{
  width: 20%;
  color: #333;
  padding-right: 20px;
  white-space: nowrap;
}

table.addressprefstable tr > .ruletype
{
  width: 180px;
}

table.addressprefstable tr > .address
{
  width: 220px;
}

table.addressprefstable tr > .action
{
  width: 100px;
  text-align: right;
}

table.langprefstable tr > .scroller,
table.addressprefstable tr > .scroller
{
  padding: 0;
}

#sections-table #rcmrowtests td.section
{
  background-image: url(images/listicons.png);
  background-position: 5px -199px;
}

#sections-table #rcmrowtests.selected td.section
{
  background-image: url(images/listicons.png);
  background-position: 5px -225px;
}

#sections-table #rcmrowbayes td.section
{
  background-image: url(images/listicons.png);
  background-position: 5px -248px;
}

#sections-table #rcmrowbayes.selected td.section
{
  background-image: url(images/listicons.png);
  background-position: 5px -270px;
}

#sections-table #rcmrowheaders td.section
{
  background-image: url(images/listicons.png);
  background-position: 5px -99px;
}

#sections-table #rcmrowheaders.selected td.section
{
  background-image: url(images/listicons.png);
  background-position: 5px -124px;
}

#sections-table #rcmrowreport td.section
{
  background-image: url(images/listicons.png);
  background-position: 5px -150px;
}

#sections-table #rcmrowreport.selected td.section
{
  background-image: url(images/listicons.png);
  background-position: 5px -174px;
}

#sections-table #rcmrowaddresses td.section
{
  background-image: url(images/listicons.png);
  background-position: 4px -50px;
}

#sections-table #rcmrowaddresses.selected td.section
{
  background-image: url(images/listicons.png);
  background-position: 4px -74px;
}